import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import {
  BlackFrame,
  BoundingBox,
  Celebrity,
  ComparedFace,
  ConnectedHomeSettingsForUpdate,
  DatasetChanges,
  DetectionFilter,
  FaceAttributes,
  FaceDetail,
  FaceMatch,
  Image,
  KinesisVideoStreamStartSelector,
  LabelDetectionFeatureName,
  LabelDetectionSettings,
  MediaAnalysisInput,
  MediaAnalysisOperationsConfig,
  MediaAnalysisOutputConfig,
  OrientationCorrection,
  ProjectVersionStatus,
  QualityFilter,
  RegionOfInterest,
  SegmentType,
  StreamProcessorDataSharingPreference,
  UserStatus,
  Video,
} from "./models_0";
import { RekognitionServiceException as __BaseException } from "./RekognitionServiceException";
export interface MatchedUser {
  UserId?: string | undefined;
  UserStatus?: UserStatus | undefined;
}
export interface NotificationChannel {
  SNSTopicArn: string | undefined;
  RoleArn: string | undefined;
}
export interface PutProjectPolicyRequest {
  ProjectArn: string | undefined;
  PolicyName: string | undefined;
  PolicyRevisionId?: string | undefined;
  PolicyDocument: string | undefined;
}
export interface PutProjectPolicyResponse {
  PolicyRevisionId?: string | undefined;
}
export interface RecognizeCelebritiesRequest {
  Image: Image | undefined;
}
export interface RecognizeCelebritiesResponse {
  CelebrityFaces?: Celebrity[] | undefined;
  UnrecognizedFaces?: ComparedFace[] | undefined;
  OrientationCorrection?: OrientationCorrection | undefined;
}
export interface SearchFacesRequest {
  CollectionId: string | undefined;
  FaceId: string | undefined;
  MaxFaces?: number | undefined;
  FaceMatchThreshold?: number | undefined;
}
export interface SearchFacesResponse {
  SearchedFaceId?: string | undefined;
  FaceMatches?: FaceMatch[] | undefined;
  FaceModelVersion?: string | undefined;
}
export interface SearchFacesByImageRequest {
  CollectionId: string | undefined;
  Image: Image | undefined;
  MaxFaces?: number | undefined;
  FaceMatchThreshold?: number | undefined;
  QualityFilter?: QualityFilter | undefined;
}
export interface SearchFacesByImageResponse {
  SearchedFaceBoundingBox?: BoundingBox | undefined;
  SearchedFaceConfidence?: number | undefined;
  FaceMatches?: FaceMatch[] | undefined;
  FaceModelVersion?: string | undefined;
}
export interface SearchUsersRequest {
  CollectionId: string | undefined;
  UserId?: string | undefined;
  FaceId?: string | undefined;
  UserMatchThreshold?: number | undefined;
  MaxUsers?: number | undefined;
}
export interface SearchedFace {
  FaceId?: string | undefined;
}
export interface SearchedUser {
  UserId?: string | undefined;
}
export interface UserMatch {
  Similarity?: number | undefined;
  User?: MatchedUser | undefined;
}
export interface SearchUsersResponse {
  UserMatches?: UserMatch[] | undefined;
  FaceModelVersion?: string | undefined;
  SearchedFace?: SearchedFace | undefined;
  SearchedUser?: SearchedUser | undefined;
}
export interface SearchUsersByImageRequest {
  CollectionId: string | undefined;
  Image: Image | undefined;
  UserMatchThreshold?: number | undefined;
  MaxUsers?: number | undefined;
  QualityFilter?: QualityFilter | undefined;
}
export interface SearchedFaceDetails {
  FaceDetail?: FaceDetail | undefined;
}
export declare const UnsearchedFaceReason: {
  readonly EXCEEDS_MAX_FACES: "EXCEEDS_MAX_FACES";
  readonly EXTREME_POSE: "EXTREME_POSE";
  readonly FACE_NOT_LARGEST: "FACE_NOT_LARGEST";
  readonly LOW_BRIGHTNESS: "LOW_BRIGHTNESS";
  readonly LOW_CONFIDENCE: "LOW_CONFIDENCE";
  readonly LOW_FACE_QUALITY: "LOW_FACE_QUALITY";
  readonly LOW_SHARPNESS: "LOW_SHARPNESS";
  readonly SMALL_BOUNDING_BOX: "SMALL_BOUNDING_BOX";
};
export type UnsearchedFaceReason =
  (typeof UnsearchedFaceReason)[keyof typeof UnsearchedFaceReason];
export interface UnsearchedFace {
  FaceDetails?: FaceDetail | undefined;
  Reasons?: UnsearchedFaceReason[] | undefined;
}
export interface SearchUsersByImageResponse {
  UserMatches?: UserMatch[] | undefined;
  FaceModelVersion?: string | undefined;
  SearchedFace?: SearchedFaceDetails | undefined;
  UnsearchedFaces?: UnsearchedFace[] | undefined;
}
export interface StartCelebrityRecognitionRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
}
export interface StartCelebrityRecognitionResponse {
  JobId?: string | undefined;
}
export declare class VideoTooLargeException extends __BaseException {
  readonly name: "VideoTooLargeException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  Logref?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<VideoTooLargeException, __BaseException>
  );
}
export interface StartContentModerationRequest {
  Video: Video | undefined;
  MinConfidence?: number | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
}
export interface StartContentModerationResponse {
  JobId?: string | undefined;
}
export interface StartFaceDetectionRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  FaceAttributes?: FaceAttributes | undefined;
  JobTag?: string | undefined;
}
export interface StartFaceDetectionResponse {
  JobId?: string | undefined;
}
export interface StartFaceSearchRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  FaceMatchThreshold?: number | undefined;
  CollectionId: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
}
export interface StartFaceSearchResponse {
  JobId?: string | undefined;
}
export interface StartLabelDetectionRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  MinConfidence?: number | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
  Features?: LabelDetectionFeatureName[] | undefined;
  Settings?: LabelDetectionSettings | undefined;
}
export interface StartLabelDetectionResponse {
  JobId?: string | undefined;
}
export interface StartMediaAnalysisJobRequest {
  ClientRequestToken?: string | undefined;
  JobName?: string | undefined;
  OperationsConfig: MediaAnalysisOperationsConfig | undefined;
  Input: MediaAnalysisInput | undefined;
  OutputConfig: MediaAnalysisOutputConfig | undefined;
  KmsKeyId?: string | undefined;
}
export interface StartMediaAnalysisJobResponse {
  JobId: string | undefined;
}
export interface StartPersonTrackingRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
}
export interface StartPersonTrackingResponse {
  JobId?: string | undefined;
}
export interface StartProjectVersionRequest {
  ProjectVersionArn: string | undefined;
  MinInferenceUnits: number | undefined;
  MaxInferenceUnits?: number | undefined;
}
export interface StartProjectVersionResponse {
  Status?: ProjectVersionStatus | undefined;
}
export interface StartShotDetectionFilter {
  MinSegmentConfidence?: number | undefined;
}
export interface StartTechnicalCueDetectionFilter {
  MinSegmentConfidence?: number | undefined;
  BlackFrame?: BlackFrame | undefined;
}
export interface StartSegmentDetectionFilters {
  TechnicalCueFilter?: StartTechnicalCueDetectionFilter | undefined;
  ShotFilter?: StartShotDetectionFilter | undefined;
}
export interface StartSegmentDetectionRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
  Filters?: StartSegmentDetectionFilters | undefined;
  SegmentTypes: SegmentType[] | undefined;
}
export interface StartSegmentDetectionResponse {
  JobId?: string | undefined;
}
export interface StreamProcessingStartSelector {
  KVSStreamStartSelector?: KinesisVideoStreamStartSelector | undefined;
}
export interface StreamProcessingStopSelector {
  MaxDurationInSeconds?: number | undefined;
}
export interface StartStreamProcessorRequest {
  Name: string | undefined;
  StartSelector?: StreamProcessingStartSelector | undefined;
  StopSelector?: StreamProcessingStopSelector | undefined;
}
export interface StartStreamProcessorResponse {
  SessionId?: string | undefined;
}
export interface StartTextDetectionFilters {
  WordFilter?: DetectionFilter | undefined;
  RegionsOfInterest?: RegionOfInterest[] | undefined;
}
export interface StartTextDetectionRequest {
  Video: Video | undefined;
  ClientRequestToken?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  JobTag?: string | undefined;
  Filters?: StartTextDetectionFilters | undefined;
}
export interface StartTextDetectionResponse {
  JobId?: string | undefined;
}
export interface StopProjectVersionRequest {
  ProjectVersionArn: string | undefined;
}
export interface StopProjectVersionResponse {
  Status?: ProjectVersionStatus | undefined;
}
export interface StopStreamProcessorRequest {
  Name: string | undefined;
}
export interface StopStreamProcessorResponse {}
export interface TagResourceRequest {
  ResourceArn: string | undefined;
  Tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateDatasetEntriesRequest {
  DatasetArn: string | undefined;
  Changes: DatasetChanges | undefined;
}
export interface UpdateDatasetEntriesResponse {}
export declare const StreamProcessorParameterToDelete: {
  readonly ConnectedHomeMinConfidence: "ConnectedHomeMinConfidence";
  readonly RegionsOfInterest: "RegionsOfInterest";
};
export type StreamProcessorParameterToDelete =
  (typeof StreamProcessorParameterToDelete)[keyof typeof StreamProcessorParameterToDelete];
export interface StreamProcessorSettingsForUpdate {
  ConnectedHomeForUpdate?: ConnectedHomeSettingsForUpdate | undefined;
}
export interface UpdateStreamProcessorRequest {
  Name: string | undefined;
  SettingsForUpdate?: StreamProcessorSettingsForUpdate | undefined;
  RegionsOfInterestForUpdate?: RegionOfInterest[] | undefined;
  DataSharingPreferenceForUpdate?:
    | StreamProcessorDataSharingPreference
    | undefined;
  ParametersToDelete?: StreamProcessorParameterToDelete[] | undefined;
}
export interface UpdateStreamProcessorResponse {}
